pub enum FunctionError {
ArgError(ArgError),
ArgCountMismatch {
expected: ArgCount,
received: usize,
},
NoOverload {
expected: HashSet<ArgumentSignature>,
received: ArgumentSignature,
},
}Available on crate feature
functions only.Expand description
An error that occurs when calling a DynamicFunction or DynamicFunctionMut.
Variants
ArgError(ArgError)
An error occurred while converting an argument.
ArgCountMismatch
The number of arguments provided does not match the expected number.
Fields
NoOverload
No overload was found for the given set of arguments.
Fields

expected: HashSet<ArgumentSignature>The set of available argument signatures.

received: ArgumentSignatureThe received argument signature.