IntoReturn

Trait IntoReturn 

pub trait IntoReturn {
    // Required method
    fn into_return<'a>(self) -> Return<'a>
       where Self: 'a;
}
Available on crate feature functions only.
A trait for types that can be converted into a Return value.

This trait exists so that types can be automatically converted into a Return by ReflectFn and ReflectFnMut.

This trait is used instead of a blanket Into implementation due to coherence issues: we can’t implement Into<Return> for both T and &T/&mut T.

This trait is automatically implemented for non-reference types when using the Reflect derive macro. Blanket impls cover &T and &mut T.

Required Methods

fn into_return<'a>(self) -> Return<'a>
where Self: 'a,

Converts Self into a Return value.

Implementations on Foreign Types

Source

impl IntoReturn for Cow<'static, str>

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for Cow<'static, Path>

Available on crate feature std only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for SocketAddr

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for EulerRot

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for TextureFormat

Available on crate feature wgpu-types only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for bool

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for char

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for f32

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for f64

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for i8

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for i16

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for i32

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for i64

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for i128

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for isize

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for u8

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for u16

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for u32

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for u64

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for u128

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for ()

Source

fn into_return<'a>(self) -> Return<'a>

Source

impl IntoReturn for usize

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for String

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for TypeId

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for RangeFull

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for AtomicBool

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for AtomicI8

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for AtomicI16

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for AtomicI32

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for AtomicI64

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for AtomicIsize

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for AtomicU8

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for AtomicU16

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for AtomicU32

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for AtomicU64

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for AtomicUsize

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for Duration

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for OsString

Available on crate feature std only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for PathBuf

Available on crate feature std only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for Instant

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for BVec2

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for BVec3

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for BVec4

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for BVec3A

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for BVec4A

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for Affine2

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for Affine3A

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for Mat3

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for Mat2

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for Mat3A

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for Mat4

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for Quat

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for Vec3A

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for Vec4

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for Vec2

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for Vec3

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for DAffine2

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for DAffine3

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for DMat2

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for DMat3

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for DMat4

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for DQuat

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for DVec2

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for DVec3

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for DVec4

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for I8Vec2

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for I8Vec3

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for I8Vec4

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for I16Vec2

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for I16Vec3

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for I16Vec4

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for IVec2

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for IVec3

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for IVec4

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for I64Vec2

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for I64Vec3

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for I64Vec4

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for U8Vec2

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for U8Vec3

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for U8Vec4

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for U16Vec2

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for U16Vec3

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for U16Vec4

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for UVec2

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for UVec3

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for UVec4

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for U64Vec2

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for U64Vec3

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for U64Vec4

Available on crate feature glam only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for NodeIndex

Available on crate feature petgraph only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for SmolStr

Available on crate feature smol_str only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for NonNilUuid

Available on crate feature uuid only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for Uuid

Available on crate feature uuid only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for BlendState

Available on crate feature wgpu-types only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for NonZeroI8

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for NonZeroI16

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for NonZeroI32

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for NonZeroI64

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for NonZeroI128

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for NonZeroIsize

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for NonZeroU8

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for NonZeroU16

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for NonZeroU32

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for NonZeroU64

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for NonZeroU128

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl IntoReturn for NonZeroUsize

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<K: FromReflect + MaybeTyped + TypePath + GetTypeRegistration + Eq + Ord, V: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for BTreeMap<K, V>

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<K: FromReflect + MaybeTyped + TypePath + GetTypeRegistration + Eq + Hash, V: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, S: TypePath + BuildHasher + Default + Send + Sync> IntoReturn for HashMap<K, V, S>

Available on crate feature std only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<K: FromReflect + MaybeTyped + TypePath + GetTypeRegistration + Eq + Hash, V: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, S: TypePath + BuildHasher + Default + Send + Sync> IntoReturn for HashMap<K, V, S>

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<K: FromReflect + MaybeTyped + TypePath + GetTypeRegistration + Eq + Hash, V: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, S: TypePath + BuildHasher + Default + Send + Sync> IntoReturn for HashMap<K, V, S>

Available on crate feature hashbrown only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<N, E, Ix> IntoReturn for DiGraph<N, E, Ix>
where DiGraph<N, E, Ix>: Any + Send + Sync, N: TypePath + Clone, E: TypePath + Clone, Ix: TypePath + IndexType,

Available on crate feature petgraph only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1)

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Source

impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2)

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Source

impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3)

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Source

impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4)

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Source

impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P5: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4, P5)

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Source

impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P5: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P6: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4, P5, P6)

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Source

impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P5: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P6: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P7: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4, P5, P6, P7)

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Source

impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P5: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P6: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P7: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P8: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4, P5, P6, P7, P8)

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Source

impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P5: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P6: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P7: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P8: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P9: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4, P5, P6, P7, P8, P9)

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Source

impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P5: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P6: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P7: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P8: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P9: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P10: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4, P5, P6, P7, P8, P9, P10)

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Source

impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P5: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P6: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P7: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P8: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P9: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P10: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P11: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4, P5, P6, P7, P8, P9, P10, P11)

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Source

impl<P: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P,)

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Source

impl<T> IntoReturn for Bound<T>
where Bound<T>: Any + Send + Sync, T: TypePath + Clone + Send + Sync,

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<T> IntoReturn for Option<T>
where Option<T>: Any + Send + Sync, T: TypePath + FromReflect + MaybeTyped + RegisterForReflection,

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<T> IntoReturn for BinaryHeap<T>
where BinaryHeap<T>: Any + Send + Sync, T: TypePath + Clone,

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<T> IntoReturn for BTreeSet<T>
where BTreeSet<T>: Any + Send + Sync, T: TypePath + Ord + Eq + Clone + Send + Sync,

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<T> IntoReturn for Arc<T>
where Arc<T>: Any + Send + Sync, T: TypePath + Send + Sync + ?Sized,

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<T> IntoReturn for Saturating<T>
where Saturating<T>: Any + Send + Sync, T: TypePath + Clone + Send + Sync,

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<T> IntoReturn for Wrapping<T>
where Wrapping<T>: Any + Send + Sync, T: TypePath + Clone + Send + Sync,

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<T> IntoReturn for Range<T>
where Range<T>: Any + Send + Sync, T: TypePath + Clone + Send + Sync,

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<T> IntoReturn for RangeFrom<T>
where RangeFrom<T>: Any + Send + Sync, T: TypePath + Clone + Send + Sync,

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<T> IntoReturn for RangeInclusive<T>
where RangeInclusive<T>: Any + Send + Sync, T: TypePath + Clone + Send + Sync,

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<T> IntoReturn for RangeTo<T>
where RangeTo<T>: Any + Send + Sync, T: TypePath + Clone + Send + Sync,

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<T> IntoReturn for RangeToInclusive<T>
where RangeToInclusive<T>: Any + Send + Sync, T: TypePath + Clone + Send + Sync,

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<T, E> IntoReturn for Result<T, E>
where Result<T, E>: Any + Send + Sync, T: TypePath + FromReflect + MaybeTyped + RegisterForReflection, E: TypePath + FromReflect + MaybeTyped + RegisterForReflection,

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<T: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for VecDeque<T>

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<T: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for Vec<T>

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<T: FromReflect + MaybeTyped + Clone + TypePath + GetTypeRegistration> IntoReturn for Cow<'static, [T]>

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<T: PartialReflect> IntoReturn for &T

Source

fn into_return<'a>(self) -> Return<'a>
where Self: 'a,

Source

impl<T: PartialReflect> IntoReturn for &mut T

Source

fn into_return<'a>(self) -> Return<'a>
where Self: 'a,

Source

impl<T: Reflect + MaybeTyped + TypePath + GetTypeRegistration, const N: usize> IntoReturn for [T; N]

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<T: SmallArray + TypePath + Send + Sync> IntoReturn for SmallVec<T>
where T::Item: FromReflect + MaybeTyped + TypePath,

Available on crate feature smallvec only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<V: Hash + Eq + FromReflect + TypePath + GetTypeRegistration, S: TypePath + BuildHasher + Default + Send + Sync> IntoReturn for HashSet<V, S>

Available on crate feature std only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<V: Hash + Eq + FromReflect + TypePath + GetTypeRegistration, S: TypePath + BuildHasher + Default + Send + Sync> IntoReturn for HashSet<V, S>

Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.
Source

impl<V: Hash + Eq + FromReflect + TypePath + GetTypeRegistration, S: TypePath + BuildHasher + Default + Send + Sync> IntoReturn for HashSet<V, S>

Available on crate feature hashbrown only.
Source

fn into_return<'into_return>(self) -> Return<'into_return>
where Self: 'into_return,

Available on crate feature functions only.

Implementors