pub trait IntoReturn {
// Required method
fn into_return<'a>(self) -> Return<'a>
where Self: 'a;
}Available on crate feature
functions only.Expand description
A trait for types that can be converted into a Return value.
This trait exists so that types can be automatically converted into a Return
by ReflectFn and ReflectFnMut.
This trait is used instead of a blanket Into implementation due to coherence issues:
we can’t implement Into<Return> for both T and &T/&mut T.
This trait is automatically implemented for non-reference types when using the Reflect
derive macro. Blanket impls cover &T and &mut T.
Required Methods
Sourcefn into_return<'a>(self) -> Return<'a>where
Self: 'a,
fn into_return<'a>(self) -> Return<'a>where
Self: 'a,
Implementations on Foreign Types
Sourceimpl IntoReturn for Cow<'static, str>
impl IntoReturn for Cow<'static, str>
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for Cow<'static, Path>
Available on crate feature std only.
impl IntoReturn for Cow<'static, Path>
Available on crate feature
std only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for SocketAddr
impl IntoReturn for SocketAddr
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for EulerRot
Available on crate feature glam only.
impl IntoReturn for EulerRot
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for TextureFormat
Available on crate feature wgpu-types only.
impl IntoReturn for TextureFormat
Available on crate feature
wgpu-types only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for bool
impl IntoReturn for bool
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for char
impl IntoReturn for char
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for f32
impl IntoReturn for f32
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for f64
impl IntoReturn for f64
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for i8
impl IntoReturn for i8
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for i16
impl IntoReturn for i16
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for i32
impl IntoReturn for i32
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for i64
impl IntoReturn for i64
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for i128
impl IntoReturn for i128
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for isize
impl IntoReturn for isize
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for u8
impl IntoReturn for u8
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for u16
impl IntoReturn for u16
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for u32
impl IntoReturn for u32
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for u64
impl IntoReturn for u64
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for u128
impl IntoReturn for u128
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for ()
impl IntoReturn for ()
fn into_return<'a>(self) -> Return<'a>
Sourceimpl IntoReturn for usize
impl IntoReturn for usize
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for String
impl IntoReturn for String
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for TypeId
impl IntoReturn for TypeId
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for RangeFull
impl IntoReturn for RangeFull
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for AtomicBool
impl IntoReturn for AtomicBool
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for AtomicI8
impl IntoReturn for AtomicI8
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for AtomicI16
impl IntoReturn for AtomicI16
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for AtomicI32
impl IntoReturn for AtomicI32
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for AtomicI64
impl IntoReturn for AtomicI64
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for AtomicIsize
impl IntoReturn for AtomicIsize
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for AtomicU8
impl IntoReturn for AtomicU8
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for AtomicU16
impl IntoReturn for AtomicU16
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for AtomicU32
impl IntoReturn for AtomicU32
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for AtomicU64
impl IntoReturn for AtomicU64
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for AtomicUsize
impl IntoReturn for AtomicUsize
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for Duration
impl IntoReturn for Duration
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for OsString
Available on crate feature std only.
impl IntoReturn for OsString
Available on crate feature
std only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for PathBuf
Available on crate feature std only.
impl IntoReturn for PathBuf
Available on crate feature
std only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for Instant
impl IntoReturn for Instant
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for BVec2
Available on crate feature glam only.
impl IntoReturn for BVec2
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for BVec3
Available on crate feature glam only.
impl IntoReturn for BVec3
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for BVec4
Available on crate feature glam only.
impl IntoReturn for BVec4
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for BVec3A
Available on crate feature glam only.
impl IntoReturn for BVec3A
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for BVec4A
Available on crate feature glam only.
impl IntoReturn for BVec4A
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for Affine2
Available on crate feature glam only.
impl IntoReturn for Affine2
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for Affine3A
Available on crate feature glam only.
impl IntoReturn for Affine3A
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for Mat3
Available on crate feature glam only.
impl IntoReturn for Mat3
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for Mat2
Available on crate feature glam only.
impl IntoReturn for Mat2
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for Mat3A
Available on crate feature glam only.
impl IntoReturn for Mat3A
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for Mat4
Available on crate feature glam only.
impl IntoReturn for Mat4
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for Quat
Available on crate feature glam only.
impl IntoReturn for Quat
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for Vec3A
Available on crate feature glam only.
impl IntoReturn for Vec3A
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for Vec4
Available on crate feature glam only.
impl IntoReturn for Vec4
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for Vec2
Available on crate feature glam only.
impl IntoReturn for Vec2
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for Vec3
Available on crate feature glam only.
impl IntoReturn for Vec3
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for DAffine2
Available on crate feature glam only.
impl IntoReturn for DAffine2
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for DAffine3
Available on crate feature glam only.
impl IntoReturn for DAffine3
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for DMat2
Available on crate feature glam only.
impl IntoReturn for DMat2
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for DMat3
Available on crate feature glam only.
impl IntoReturn for DMat3
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for DMat4
Available on crate feature glam only.
impl IntoReturn for DMat4
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for DQuat
Available on crate feature glam only.
impl IntoReturn for DQuat
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for DVec2
Available on crate feature glam only.
impl IntoReturn for DVec2
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for DVec3
Available on crate feature glam only.
impl IntoReturn for DVec3
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for DVec4
Available on crate feature glam only.
impl IntoReturn for DVec4
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for I8Vec2
Available on crate feature glam only.
impl IntoReturn for I8Vec2
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for I8Vec3
Available on crate feature glam only.
impl IntoReturn for I8Vec3
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for I8Vec4
Available on crate feature glam only.
impl IntoReturn for I8Vec4
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for I16Vec2
Available on crate feature glam only.
impl IntoReturn for I16Vec2
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for I16Vec3
Available on crate feature glam only.
impl IntoReturn for I16Vec3
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for I16Vec4
Available on crate feature glam only.
impl IntoReturn for I16Vec4
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for IVec2
Available on crate feature glam only.
impl IntoReturn for IVec2
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for IVec3
Available on crate feature glam only.
impl IntoReturn for IVec3
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for IVec4
Available on crate feature glam only.
impl IntoReturn for IVec4
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for I64Vec2
Available on crate feature glam only.
impl IntoReturn for I64Vec2
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for I64Vec3
Available on crate feature glam only.
impl IntoReturn for I64Vec3
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for I64Vec4
Available on crate feature glam only.
impl IntoReturn for I64Vec4
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for U8Vec2
Available on crate feature glam only.
impl IntoReturn for U8Vec2
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for U8Vec3
Available on crate feature glam only.
impl IntoReturn for U8Vec3
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for U8Vec4
Available on crate feature glam only.
impl IntoReturn for U8Vec4
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for U16Vec2
Available on crate feature glam only.
impl IntoReturn for U16Vec2
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for U16Vec3
Available on crate feature glam only.
impl IntoReturn for U16Vec3
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for U16Vec4
Available on crate feature glam only.
impl IntoReturn for U16Vec4
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for UVec2
Available on crate feature glam only.
impl IntoReturn for UVec2
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for UVec3
Available on crate feature glam only.
impl IntoReturn for UVec3
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for UVec4
Available on crate feature glam only.
impl IntoReturn for UVec4
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for U64Vec2
Available on crate feature glam only.
impl IntoReturn for U64Vec2
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for U64Vec3
Available on crate feature glam only.
impl IntoReturn for U64Vec3
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for U64Vec4
Available on crate feature glam only.
impl IntoReturn for U64Vec4
Available on crate feature
glam only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for NodeIndex
Available on crate feature petgraph only.
impl IntoReturn for NodeIndex
Available on crate feature
petgraph only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for SmolStr
Available on crate feature smol_str only.
impl IntoReturn for SmolStr
Available on crate feature
smol_str only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for NonNilUuid
Available on crate feature uuid only.
impl IntoReturn for NonNilUuid
Available on crate feature
uuid only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for Uuid
Available on crate feature uuid only.
impl IntoReturn for Uuid
Available on crate feature
uuid only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for BlendState
Available on crate feature wgpu-types only.
impl IntoReturn for BlendState
Available on crate feature
wgpu-types only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for NonZeroI8
impl IntoReturn for NonZeroI8
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for NonZeroI16
impl IntoReturn for NonZeroI16
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for NonZeroI32
impl IntoReturn for NonZeroI32
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for NonZeroI64
impl IntoReturn for NonZeroI64
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for NonZeroI128
impl IntoReturn for NonZeroI128
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for NonZeroIsize
impl IntoReturn for NonZeroIsize
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for NonZeroU8
impl IntoReturn for NonZeroU8
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for NonZeroU16
impl IntoReturn for NonZeroU16
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for NonZeroU32
impl IntoReturn for NonZeroU32
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for NonZeroU64
impl IntoReturn for NonZeroU64
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for NonZeroU128
impl IntoReturn for NonZeroU128
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl IntoReturn for NonZeroUsize
impl IntoReturn for NonZeroUsize
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<K: FromReflect + MaybeTyped + TypePath + GetTypeRegistration + Eq + Ord, V: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for BTreeMap<K, V>
impl<K: FromReflect + MaybeTyped + TypePath + GetTypeRegistration + Eq + Ord, V: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for BTreeMap<K, V>
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<K: FromReflect + MaybeTyped + TypePath + GetTypeRegistration + Eq + Hash, V: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, S: TypePath + BuildHasher + Default + Send + Sync> IntoReturn for HashMap<K, V, S>
Available on crate feature std only.
impl<K: FromReflect + MaybeTyped + TypePath + GetTypeRegistration + Eq + Hash, V: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, S: TypePath + BuildHasher + Default + Send + Sync> IntoReturn for HashMap<K, V, S>
Available on crate feature
std only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<K: FromReflect + MaybeTyped + TypePath + GetTypeRegistration + Eq + Hash, V: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, S: TypePath + BuildHasher + Default + Send + Sync> IntoReturn for HashMap<K, V, S>
impl<K: FromReflect + MaybeTyped + TypePath + GetTypeRegistration + Eq + Hash, V: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, S: TypePath + BuildHasher + Default + Send + Sync> IntoReturn for HashMap<K, V, S>
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<K: FromReflect + MaybeTyped + TypePath + GetTypeRegistration + Eq + Hash, V: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, S: TypePath + BuildHasher + Default + Send + Sync> IntoReturn for HashMap<K, V, S>
Available on crate feature hashbrown only.
impl<K: FromReflect + MaybeTyped + TypePath + GetTypeRegistration + Eq + Hash, V: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, S: TypePath + BuildHasher + Default + Send + Sync> IntoReturn for HashMap<K, V, S>
Available on crate feature
hashbrown only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<N, E, Ix> IntoReturn for DiGraph<N, E, Ix>
Available on crate feature petgraph only.
impl<N, E, Ix> IntoReturn for DiGraph<N, E, Ix>
Available on crate feature
petgraph only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1)
impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1)
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Sourceimpl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2)
impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2)
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Sourceimpl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3)
impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3)
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Sourceimpl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4)
impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4)
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Sourceimpl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P5: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4, P5)
impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P5: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4, P5)
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Sourceimpl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P5: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P6: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4, P5, P6)
impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P5: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P6: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4, P5, P6)
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Sourceimpl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P5: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P6: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P7: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4, P5, P6, P7)
impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P5: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P6: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P7: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4, P5, P6, P7)
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Sourceimpl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P5: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P6: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P7: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P8: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4, P5, P6, P7, P8)
impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P5: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P6: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P7: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P8: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4, P5, P6, P7, P8)
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Sourceimpl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P5: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P6: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P7: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P8: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P9: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4, P5, P6, P7, P8, P9)
impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P5: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P6: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P7: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P8: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P9: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4, P5, P6, P7, P8, P9)
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Sourceimpl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P5: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P6: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P7: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P8: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P9: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P10: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4, P5, P6, P7, P8, P9, P10)
impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P5: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P6: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P7: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P8: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P9: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P10: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4, P5, P6, P7, P8, P9, P10)
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Sourceimpl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P5: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P6: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P7: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P8: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P9: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P10: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P11: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4, P5, P6, P7, P8, P9, P10, P11)
impl<P0: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P1: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P2: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P3: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P4: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P5: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P6: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P7: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P8: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P9: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P10: FromReflect + MaybeTyped + TypePath + GetTypeRegistration, P11: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P0, P1, P2, P3, P4, P5, P6, P7, P8, P9, P10, P11)
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Sourceimpl<P: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P,)
impl<P: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for (P,)
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Sourceimpl<T> IntoReturn for Bound<T>
impl<T> IntoReturn for Bound<T>
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<T> IntoReturn for Option<T>
impl<T> IntoReturn for Option<T>
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<T> IntoReturn for BinaryHeap<T>
impl<T> IntoReturn for BinaryHeap<T>
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<T> IntoReturn for BTreeSet<T>
impl<T> IntoReturn for BTreeSet<T>
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<T> IntoReturn for Arc<T>
impl<T> IntoReturn for Arc<T>
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<T> IntoReturn for Saturating<T>
impl<T> IntoReturn for Saturating<T>
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<T> IntoReturn for Wrapping<T>
impl<T> IntoReturn for Wrapping<T>
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<T> IntoReturn for Range<T>
impl<T> IntoReturn for Range<T>
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<T> IntoReturn for RangeFrom<T>
impl<T> IntoReturn for RangeFrom<T>
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<T> IntoReturn for RangeInclusive<T>
impl<T> IntoReturn for RangeInclusive<T>
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<T> IntoReturn for RangeTo<T>
impl<T> IntoReturn for RangeTo<T>
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<T> IntoReturn for RangeToInclusive<T>
impl<T> IntoReturn for RangeToInclusive<T>
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<T, E> IntoReturn for Result<T, E>where
Result<T, E>: Any + Send + Sync,
T: TypePath + FromReflect + MaybeTyped + RegisterForReflection,
E: TypePath + FromReflect + MaybeTyped + RegisterForReflection,
impl<T, E> IntoReturn for Result<T, E>where
Result<T, E>: Any + Send + Sync,
T: TypePath + FromReflect + MaybeTyped + RegisterForReflection,
E: TypePath + FromReflect + MaybeTyped + RegisterForReflection,
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<T: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for VecDeque<T>
impl<T: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for VecDeque<T>
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<T: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for Vec<T>
impl<T: FromReflect + MaybeTyped + TypePath + GetTypeRegistration> IntoReturn for Vec<T>
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<T: FromReflect + MaybeTyped + Clone + TypePath + GetTypeRegistration> IntoReturn for Cow<'static, [T]>
impl<T: FromReflect + MaybeTyped + Clone + TypePath + GetTypeRegistration> IntoReturn for Cow<'static, [T]>
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<T: PartialReflect> IntoReturn for &T
impl<T: PartialReflect> IntoReturn for &T
fn into_return<'a>(self) -> Return<'a>where
Self: 'a,
Sourceimpl<T: PartialReflect> IntoReturn for &mut T
impl<T: PartialReflect> IntoReturn for &mut T
fn into_return<'a>(self) -> Return<'a>where
Self: 'a,
Sourceimpl<T: Reflect + MaybeTyped + TypePath + GetTypeRegistration, const N: usize> IntoReturn for [T; N]
impl<T: Reflect + MaybeTyped + TypePath + GetTypeRegistration, const N: usize> IntoReturn for [T; N]
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<T: SmallArray + TypePath + Send + Sync> IntoReturn for SmallVec<T>
Available on crate feature smallvec only.
impl<T: SmallArray + TypePath + Send + Sync> IntoReturn for SmallVec<T>
Available on crate feature
smallvec only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<V: Hash + Eq + FromReflect + TypePath + GetTypeRegistration, S: TypePath + BuildHasher + Default + Send + Sync> IntoReturn for HashSet<V, S>
Available on crate feature std only.
impl<V: Hash + Eq + FromReflect + TypePath + GetTypeRegistration, S: TypePath + BuildHasher + Default + Send + Sync> IntoReturn for HashSet<V, S>
Available on crate feature
std only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<V: Hash + Eq + FromReflect + TypePath + GetTypeRegistration, S: TypePath + BuildHasher + Default + Send + Sync> IntoReturn for HashSet<V, S>
impl<V: Hash + Eq + FromReflect + TypePath + GetTypeRegistration, S: TypePath + BuildHasher + Default + Send + Sync> IntoReturn for HashSet<V, S>
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.Sourceimpl<V: Hash + Eq + FromReflect + TypePath + GetTypeRegistration, S: TypePath + BuildHasher + Default + Send + Sync> IntoReturn for HashSet<V, S>
Available on crate feature hashbrown only.
impl<V: Hash + Eq + FromReflect + TypePath + GetTypeRegistration, S: TypePath + BuildHasher + Default + Send + Sync> IntoReturn for HashSet<V, S>
Available on crate feature
hashbrown only.Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
Self: 'into_return,
Available on crate feature
functions only.