pub struct DynamicEnum { /* private fields */ }Expand description
A dynamic representation of an enum.
This allows for enums to be configured at runtime.
Example
// The original enum value
let mut value: Option<usize> = Some(123);
// Create a DynamicEnum to represent the new value
let mut dyn_enum = DynamicEnum::new(
"None",
DynamicVariant::Unit
);
// Apply the DynamicEnum as a patch to the original value
value.apply(dyn_enum.as_partial_reflect());
// Tada!
assert_eq!(None, value);Implementations
Sourceimpl DynamicEnum
impl DynamicEnum
Sourcepub fn new<I: Into<String>, V: Into<DynamicVariant>>(
variant_name: I,
variant: V,
) -> Self
pub fn new<I: Into<String>, V: Into<DynamicVariant>>( variant_name: I, variant: V, ) -> Self
Create a new DynamicEnum to represent an enum at runtime.
Arguments
variant_name: The name of the variant to setvariant: The variant data
Sourcepub fn new_with_index<I: Into<String>, V: Into<DynamicVariant>>(
variant_index: usize,
variant_name: I,
variant: V,
) -> Self
pub fn new_with_index<I: Into<String>, V: Into<DynamicVariant>>( variant_index: usize, variant_name: I, variant: V, ) -> Self
Create a new DynamicEnum with a variant index to represent an enum at runtime.
Arguments
variant_index: The index of the variant to setvariant_name: The name of the variant to setvariant: The variant data
Sourcepub fn set_represented_type(
&mut self,
represented_type: Option<&'static TypeInfo>,
)
pub fn set_represented_type( &mut self, represented_type: Option<&'static TypeInfo>, )
Sets the type to be represented by this DynamicEnum.
Panics
Panics if the given type is not a TypeInfo::Enum.
Sourcepub fn set_variant<I: Into<String>, V: Into<DynamicVariant>>(
&mut self,
name: I,
variant: V,
)
pub fn set_variant<I: Into<String>, V: Into<DynamicVariant>>( &mut self, name: I, variant: V, )
Set the current enum variant represented by this struct.
Sourcepub fn set_variant_with_index<I: Into<String>, V: Into<DynamicVariant>>(
&mut self,
variant_index: usize,
variant_name: I,
variant: V,
)
pub fn set_variant_with_index<I: Into<String>, V: Into<DynamicVariant>>( &mut self, variant_index: usize, variant_name: I, variant: V, )
Set the current enum variant represented by this struct along with its variant index.
Sourcepub fn variant(&self) -> &DynamicVariant
pub fn variant(&self) -> &DynamicVariant
Get a reference to the DynamicVariant contained in self.
Sourcepub fn variant_mut(&mut self) -> &mut DynamicVariant
pub fn variant_mut(&mut self) -> &mut DynamicVariant
Get a mutable reference to the DynamicVariant contained in self.
Using the mut reference to switch to a different variant will not update the internal tracking of the variant name and index.
If you want to switch variants, prefer one of the setters:
DynamicEnum::set_variant or DynamicEnum::set_variant_with_index.
Sourcepub fn from<TEnum: Enum>(value: TEnum) -> Self
pub fn from<TEnum: Enum>(value: TEnum) -> Self
Create a DynamicEnum from an existing one.
This is functionally the same as DynamicEnum::from_ref except it takes an owned value.
Sourcepub fn from_ref<TEnum: Enum + ?Sized>(value: &TEnum) -> Self
pub fn from_ref<TEnum: Enum + ?Sized>(value: &TEnum) -> Self
Create a DynamicEnum from an existing one.
This is functionally the same as DynamicEnum::from except it takes a reference.